package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`MP`!````8"-```````!``````````("C````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````;`````````!L``````````0`````````!````
M!0````````````````!``````````$```````(26````````A)8`````````
M``$```````$````&````P)T```````#`G4$``````,"=00``````<`0`````
M``#(%````````````0```````@````8```#8G0```````-B=00``````V)U!
M`````````@`````````"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#`G0```````,"=00``````P)U!``````!``@``````
M`$`"`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`]HTEB5FKDX?!CCEP:#,/R5\[;?!A````!0```!`````*````H!``*`)&
M$0```&``5@)0&(((`"!(`!`1``@0`@`@`````````$@"(`X`"@``A`*H00`%
M(&@(A$DX0A25!D$H"BA8B($%8`26"`E"2G!``!@!`4!""`!`@(S`!``($)`0
M`P$`"($8@(%`0(*9@"Q`"`(!!"``8``)!)$C!(J74&`%``````````8````'
M````"0`````````````````````````*````#`````T````/````$````!$`
M```3````%@`````````````````````````8````&P```!P`````````(```
M`"$````B`````````",````D````*``````````J```````````````K````
M+````"T````N`````````#(````S`````````#<``````````````#@````[
M````/``````````]````/@```$````!"````10````````!'````2````$D`
M``!*`````````$L```````````````````````````````````!,````30``
M``````!/`````````%$```!3````50````````````````````````!6````
M6@````````!<`````````%T`````````7P```&```````````````&(```!C
M````90```&8```!I````7Y:3'*-:[Y#"CH?_5]N3'`TZEPO2402$@72"#7OP
M2FMV5#R4S3\,K_<CSB")!W#3('2P`M5DU'QFK\QF+DX]]MOW`%X&I(?_`:\T
MZ,[>1RW@IP(*STJN_^-'Q@$^?I9\Q@[@/>P_D`)M<X7%Q8D%D&&8[Q(!(_FD
MG;N3'$)%U>Q\[1$/4.X1XX?YG(%:FCL/NY63'$%-G7RGW:-K6>^7>3GRBQP,
M%.*>!#*EA:("]AG;S>.>^Z%L8.K3[P[(.4`?,F+;[;F-\0[I^\/"[-Z3'$HB
M??\+BA!7K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_+)@BU&BZXY)\(?_D
M#HJ8W<)O>FGZDZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`4!M]7S&X@@V^VE<;
MLP&+;W9OXW"]T$M]GB+'J&L)0]8A8F0'?JF<FV+0^H+L+/:+:W^:?-"?+/R'
M\)9\[PM1^9!U@@U#9DL0!6RRS3RM.0T7ZEKQH^#[2>)7Q!A7DEI2_=+O#V[%
MWQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````````````````````
M`!$````@`````````````````````````"T````@````````````````````
M`````#P````@`````````````````````````%`````@````````````````
M`````````$,#```2``````````````````````````8"```2````````````
M`````````````($"```2`````````````````````````)T"```2````````
M`````````````````#@$```@`!<`$*)!`````````````````)L!```2````
M`````````````````````'H"```2`````````````````````````(L!```2
M````X!U``````````````````*$#```0`!@`,*)!`````````````````#0"
M```2`````````````````````````%\"```2````````````````````````
M`'@$```1`!<`**)!```````(`````````.`"```2````````````````````
M`````,0$```2``T`L$Y```````#P`P```````!T$```2``T`&$!````````X
M`0```````$H#```2`````````````````````````$4"```2````````````
M`````````````/$"```2`````````````````````````+`#```0`!@`B+)!
M`````````````````"D$```2``T`,$5```````!\"0```````%($```2``T`
M*#U```````#<`````````/L#```2`````````````````````````!`$```2
M``T`^#]````````@`````````"\"```2`````````````````````````&P"
M```2`````````````````````````&0!```2````````````````````````
M`,T"```2`````````````````````````%T#```A`!@`4*)!```````(````
M`````.X!```2`````````````````````````/4!```2````````````````
M`````````(\"```2`````````````````````````(X#```0`!<`,*)!````
M`````````````'0"```2`````````````````````````*H"```2````````
M`````````````````(<````2````L"!``````````````````.@!```2````
M`````````````````````!4#```2``````````````````````````X"```2
M`````````````````````````%X#```A`!@`4*)!```````(`````````+L#
M```0`!@`B+)!`````````````````.H"```1`!@`,*)!```````(````````
M`,@#```2``T`M%-````````$`````````&\!```2````````````````````
M`````$L!```2`````````````````````````&@$```2``T`/%-```````!X
M`````````*0$```2``T`\$-````````\`0```````-(#```2``X`N%-`````
M`````````````$X"```2`````````````````````````#P$```2``T`8"-`
M`````````````````)$$```2``L`^!Q``````````````````*<````2````
M`````````````````````(@"```2`````````````````````````+\"```2
M`````````````````````````.L````1`!@`0*)!```````!`````````$,$
M```1``\`R%-````````$`````````)4#```0`!@`,*)!````````````````
M`!P#```2`````````````````````````#0#```2````````````````````
M`````&H````2`````````````````````````/@````2````````````````
M`````````(\$```2``T`H#Q````````T`````````!0!```2````````````
M`````````````,,#```0`!@`B+)!`````````````````)<$```2``T`$#Y`
M``````#D`0```````+P````2`````````````````````````!T"```2````
M`````````````````````-0!```2`````````````````````````'T!```2
M`````````````````````````,H````2`````````````````````````-P`
M```2``````````````````````````D!```1`!@`.*)!```````$````````
M`%P#```1`!@`4*)!```````(`````````#T!```2````````````````````
M`````)8"```2`````````````````````````*\#```0`!@`B+)!````````
M`````````+8$```2``T`,$-```````"8`````````-@"```2````````````
M`````````````)@````2`````````````````````````"8#```2````````
M`````````````````#8$```0`!<`$*)!`````````````````'P#```1`!@`
M2*)!```````(`````````.D#```2``T`R$-````````H`````````+D!```2
M`````````````````````````*8!```2`````````````````````````%<#
M```2``T`4"%````````0`@````````$#```2````````````````````````
M`!D!```2`````````````````````````/@"```2````````````````````
M`````+@"```2`````````````````````````*0"```2````````````````
M`````````#P"```2`````````````````````````+(!```2````````````
M`````````````#P#```2`````````````````````````(($```2``T`4$%`
M``````#<`0````````@#```2`````````````````````````!X!```2````
M`````````````````````&8"```2``````````````````````````0$```2
M``T`H%)```````"``````````'@````2`````````````````````````%L!
M```2`````````````````````````-@#```2``T`"#Y````````$````````
M`"H!```2````("!```````````````````!L:6)P97)L+G-O+C4N,C(`7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]2
M96=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L
M7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF
M=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R
M;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;&EB<'1H<F5A9"YS;RXP`'!T
M:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I
M;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E
M>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I
M;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T
M<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK
M`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS
M=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?
M8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI
M;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K7V-H:U]G=6%R9`!?961A=&$`7U]B
M<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E
M;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A
M<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN
M7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M
M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A
M<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]"3T]4`$=,24)#7S(N,3<````````````````"``,``@`"``$````"````
M`0`"``(``0`"``$``0`"``(``@`!``$``0`"``$``@`"`````@`"``,``P`"
M``$``@`"`````P`"``,``@`!``(``0```````0`!``$``@`!``$````"``(`
M```!``$``@`"```````!`````0`!`````@`#`````````````@````(``0`!
M``(````"``$`!``!```````!``(``@`"``(``@`"``(``@`!``(````"``$`
M``````$``````````0`!`&8#```0````(````)>1E@8```0`V@0````````!
M``$`Q`$``!`````@````EY&6!@```P#:!`````````$``0`3`@``$```````
M``"7D98&```"`-H$````````X)]!```````!!````@``````````````,*)!
M````````!```+0``````````````.*)!````````!```2P``````````````
M0*)!````````!```.@``````````````2*)!````````!```50``````````
M````4*)!````````!```3````````````````*!!```````"!```70``````
M````````"*!!```````"!```/@``````````````$*!!```````"!```.```
M````````````&*!!```````"!```(P``````````````(*!!```````"!```
M4P``````````````**!!```````"!```'```````````````,*!!```````"
M!```$0``````````````.*!!```````"!```7```````````````0*!!````
M```"!```%@``````````````2*!!```````"!```40``````````````4*!!
M```````"!```10``````````````6*!!```````"!```#```````````````
M8*!!```````"!```1@``````````````:*!!```````"!```7P``````````
M````<*!!```````"!```4@``````````````>*!!```````"!```0@``````
M````````@*!!```````"!```8P``````````````B*!!```````"!```!P``
M````````````D*!!```````"!```8```````````````F*!!```````"!```
M.0``````````````H*!!```````"!```+P``````````````J*!!```````"
M!```30``````````````L*!!```````"!```#@``````````````N*!!````
M```"!```%```````````````P*!!```````"!```3@``````````````R*!!
M```````"!```20``````````````T*!!```````"!```5P``````````````
MV*!!```````"!```!@``````````````X*!!```````"!```6```````````
M````Z*!!```````"!```1P``````````````\*!!```````"!```'0``````
M````````^*!!```````"!```%0```````````````*%!```````"!```-```
M````````````"*%!```````"!```*```````````````$*%!```````"!```
M,```````````````&*%!```````"!````@``````````````(*%!```````"
M!```)0``````````````**%!```````"!```80``````````````,*%!````
M```"!```9P``````````````.*%!```````"!```6@``````````````0*%!
M```````"!```)@``````````````2*%!```````"!```!0``````````````
M4*%!```````"!```&@``````````````6*%!```````"!```7@``````````
M````8*%!```````"!```-P``````````````:*%!```````"!```'@``````
M````````<*%!```````"!```'P``````````````>*%!```````"!```:@``
M````````````@*%!```````"!```6P``````````````B*%!```````"!```
M/P``````````````D*%!```````"!```/0``````````````F*%!```````"
M!```9```````````````H*%!```````"!```"@``````````````J*%!````
M```"!```0```````````````L*%!```````"!```*0``````````````N*%!
M```````"!```2```````````````P*%!```````"!```)P``````````````
MR*%!```````"!```*@``````````````T*%!```````"!```"P``````````
M````V*%!```````"!```(0``````````````X*%!```````"!```2@``````
M````````Z*%!```````"!```:```````````````\*%!```````"!```"```
M````````````^*%!```````"!```(@```````````````*)!```````"!```
M#P``````````````"*)!```````"!```90``````````````_7N_J?T#`)&J
M`0"4_7O!J,`#7]8`````\'N_J=```)`1_D?Y$.(_D2`"']8?(`/5'R`#U1\@
M`]70``"P$0)`^1`"`)$@`A_6T```L!$&0/D0(@"1(`(?UM```+`1"D#Y$$(`
MD2`"'];0``"P$0Y`^1!B`)$@`A_6T```L!$20/D0@@"1(`(?UM```+`1%D#Y
M$*(`D2`"'];0``"P$1I`^1#"`)$@`A_6T```L!$>0/D0X@"1(`(?UM```+`1
M(D#Y$`(!D2`"'];0``"P$29`^1`B`9$@`A_6T```L!$J0/D00@&1(`(?UM``
M`+`1+D#Y$&(!D2`"'];0``"P$3)`^1""`9$@`A_6T```L!$V0/D0H@&1(`(?
MUM```+`1.D#Y$,(!D2`"'];0``"P$3Y`^1#B`9$@`A_6T```L!%"0/D0`@*1
M(`(?UM```+`11D#Y$"("D2`"'];0``"P$4I`^1!"`I$@`A_6T```L!%.0/D0
M8@*1(`(?UM```+`14D#Y$(("D2`"'];0``"P$59`^1"B`I$@`A_6T```L!%:
M0/D0P@*1(`(?UM```+`17D#Y$.("D2`"'];0``"P$6)`^1`"`Y$@`A_6T```
ML!%F0/D0(@.1(`(?UM```+`1:D#Y$$(#D2`"'];0``"P$6Y`^1!B`Y$@`A_6
MT```L!%R0/D0@@.1(`(?UM```+`1=D#Y$*(#D2`"'];0``"P$7I`^1#"`Y$@
M`A_6T```L!%^0/D0X@.1(`(?UM```+`1@D#Y$`($D2`"'];0``"P$89`^1`B
M!)$@`A_6T```L!&*0/D00@21(`(?UM```+`1CD#Y$&($D2`"'];0``"P$9)`
M^1""!)$@`A_6T```L!&60/D0H@21(`(?UM```+`1FD#Y$,($D2`"'];0``"P
M$9Y`^1#B!)$@`A_6T```L!&B0/D0`@61(`(?UM```+`1ID#Y$"(%D2`"'];0
M``"P$:I`^1!"!9$@`A_6T```L!&N0/D08@61(`(?UM```+`1LD#Y$((%D2`"
M'];0``"0$;9`^1"B!9$@`A_6T```D!&Z0/D0P@61(`(?UM```)`1OD#Y$.(%
MD2`"'];0``"0$<)`^1`"!I$@`A_6T```D!'&0/D0(@:1(`(?UM```)`1RD#Y
M$$(&D2`"'];0``"0$<Y`^1!B!I$@`A_6T```D!'20/D0@@:1(`(?UM```)`1
MUD#Y$*(&D2`"'];0``"0$=I`^1#"!I$@`A_6T```D!'>0/D0X@:1(`(?UM``
M`)`1XD#Y$`('D2`"'];0``"0$>9`^1`B!Y$@`A_6T```D!'J0/D00@>1(`(?
MUM```)`1[D#Y$&('D2`"'];0``"0$?)`^1""!Y$@`A_6T```D!'V0/D0H@>1
M(`(?UM```)`1^D#Y$,('D2`"'];0``"0$?Y`^1#B!Y$@`A_6T```D!$"0?D0
M`@B1(`(?UM```)`1!D'Y$"((D2`"'];]>[JI_0,`D?-3`:G4``"0]5L"J8,B
M"9&BAP.IH0,!D60`0/FD+P#Y!`"`TJ!/`+FBXP"1H#,!D=,``+#5``"0@/__
MEP(``)````"00H``D0#``I'A`P*J7@P`E,```)```$DY0`$`-4;__Y=B@@V1
M0``2^*`,`+35``"0$?__EZ`Z0KE+__^7'U0D.:`Z0KE(__^7X@,`JJ`Z0KE!
M2%0Y(0`?,D%(%#E"__^7`4A4.2$``#(!2!0YH$]`N0`4`!$`?'V3-___EZ0C
M0/G&``"088(-D:)/0+D%``#P`P``\,<40?F(`(!2A@!`^:6@()%CP""17P0`
M<084`*D'#`&I*(`0N"``$?BM!@!4A"``D4,0`!&A`(!2YP"`DN7,(8N&A$#X
M(00`$3\``VL&:"7X8?__5':"#9$%S".+`0``L.,#`*I"#``1(6`SD<`"4O@$
M`(#2OX`?^'+__Y?U`P`JX`(`-':"#9'``E+X[?[_EP```/"A4P&1`"`6D=,$
M`)1@`@"T<X(-D90B"9%@`E+XT/[_EU?__Y>B+T#Y@0)`^4$``<K@`Q4JX0(`
MM?-30:GU6T*I_7O&J,`#7];``E+X?/__E_4#`"KG__\7P()1^*```+3?"P"4
MZ___%T,`"`O5__\7````\*%3`9$`0!21M@0`E,""$?A@_/^TU0L`E.'__Q?W
M_O^7(`"`4HG^_Y<=`(#2'@"`TN4#`*KA`T#YXB,`D>8#`)'```!8XP``6`0!
M`%C'_O^7^O[_EP````!0(4```````#Q30```````M%-```````"@``#P`/!'
M^4```+3K_O\7P`-?U@````#!``"0P```D"'`")$`P`B1(1P`D2$``,L_.`#Q
MJ0``5`$``)`A_$'Y00``M"``'];``U_6'R`#U0``````````P0``D,```)`A
MP`B1`,`(D2$``,LA_$.3(?Q!BR'\09/!``"T`@``D$(@0OEB``"T0``?UA\@
M`]7``U_6'R`#U0``````````_7N^J?T#`)'S"P#YTP``D&!B23F````UV/__
MER``@%)@8@DY\PM`^?U[PJC``U_6H```\`!`-Y$!`$#Y80``M=[__Q<?(`/5
M`0``D"%80OF!__^T_7N_J?T#`)$@`#_6_7O!J-7__Q<``````````/]#"M'(
M``"0`2$)D0;@`)$)X`&1_7N_J?T#`)$B`$#YHD\!^0(`@-*B8P"1Y0,"JL,`
M0+FE0`"1P81`^&,(P%JC`!_XWP`)ZR3\8-,G_&C3@]QXT^<<>)*$'&C38QQP
MDN'@0:J#``.J80`!JJ&`'_@!_O]4IF,(D4,`0/E"(`"1101`^4$<0/E$,$#Y
MHP`#RE\`!NN!``'*80`!RB/\7]-A!`&J(7Q`DD$\`/EA_O]4`QQ`J2$SC]($
M&$&IX`!GGL$`9YYE_%O3@@!GG@D00/FB#T#YI10#JD%0J_(((0F1(@$"BT`<
M82YA`&>>"@!FGD5!)8NB``*+Y?Q"TT(``8NE>`>J2WQ`DJ5\0)*@`&>>K@`K
MBJ430/EJ_5O3Q0`%BTH5"ZH!'&(N+`!FGHP!`8N%`06+;/Q"TXQY`ZJJ0"J+
MC'U`DDU]0))"``R*I1=`^<(!`JJ/`2V*A0`%BT(``8M"``6+I?U;TZ44#:I%
M0"6+8OU"TT)X"ZJK?$"23GQ`DJ(;0/E*`0Z*T`$KBNH!"JH/`&:>0@`!BTH!
M#XM*`0*+8OU;TT(4"ZI"02*+JOU"TTIY#:JM'T#Y3WU`DDI\0)*E``^*K0$!
MBP4"!:KP`2J*I0`,BTS]6].E``V+C!4*JJ5`+(ML_4+3BWD+JFU]0)*K?$"2
M3``-BJ(C0/D,`@RJL`$KBHP!#HM"``&+@@$"BVS]6].,%0NJ0D`LBTS]0M.*
M>0JJ3GU`DDI\0)*E``Z*!0(%JM`!*HJE``^+K+]$J8P!`8OO`0&+I0`,BTS]
M6].,%0JJI4`LBVS]0M.+>0NJ;'U`DJM\0))"``R*`@("JI`!*XI"``V+;?U;
MTT(`#XNO+T#YK14+JN\!`8M"0"V+3?U"TZIY"JI-?4"22GQ`DJ4`#8H%`@6J
ML`$JBJ4`#HM._5O3I0`/BZ\S0/G.%0JJ[P$!BZ5`+HMN_4+3RWD+JFY]0)*K
M?$"20@`.B@("`JK0`2N*0@`,BVS]6]-"``^+KS=`^8P5"ZKO`0&+0D`LBTS]
M0M.*>0JJ3'U`DDI\0)*E``R*!0(%JI`!*HJE``V+3?U;TZ4`#XNO.T#YK14*
MJN\!`8NE0"V+;?U"TZMY"ZIM?4"2JWQ`DD(`#8H"`@*JL`$KBD(`#HMN_5O3
M0@`/BZ\_0/G.%0NJ[P$!BT)`+HM._4+3RGD*JDY]0))*?$"2I0`.B@4"!:K0
M`2J*I0`,BTS]6].E``^+KT-`^8P5"JKO`0&+I4`LBVS]0M.+>0NJ;'U`DJM\
M0))"``R*`@("JI`!*XI"``V+;?U;TT(`#XNO1T#YK14+JN\!`8M"0"V+3?U"
MTZIY"JI-?4"22GQ`DJ4`#8H%`@6JI0`.BT[]6].E``^+SA4*JJ5`+HMN_4+3
ML7Q`DLMY"ZJN2T#Y;WU`DJL!*HI"``^*S@$!BV(!`JHK_EO30@`,BVL5$:I"
M``Z+0D`KBTO]0M-0?$"2:GD*JDY]0)*J3T#YK``.BN4!,8JL``RJ2P$!BR7^
M0M.*`0V+2@$+BPO^6].E>!&JK7Q`DFL5$*I,``V*P@$PBDM!*XM,``RJ97U`
MDHP!#XNJ/TJIHOQ;TTH!`8M"%`6JB@$*B^\!`8M*02*+`OY"TTQ]0))">!"J
ML`$EBD)\0))K`0**"P(+JK!;0/EK`0Z+COU;TVL!#XL!`@&+SA4,JE``+(IN
M02Z+J_Q"TV5Y!:K+?4"2KWQ`DDH!#XH*`@JJ2@$-BT$!`8MJ_5O32A4+JBI`
M*HN!_4+34'U`DBQX#*HA=)W2I0`,RB';K?*E``Y*H@`"BZ6W2ZFE``&+K0$!
MBT4`!8L"_EO30A00JJ)`(HME_4+33GQ`DJMX"ZJ%`0O*I0`*2@K^0M.E``^+
MK0`-B\7]6]-*>1"J;P$*RJ44#JKB`0)*I4$EBZU\0)),0"R+HF=`^4(``8N,
M`0*+HOU;TT(4#:J"02*+S/U"TXYY#JI,?$"23P$.RN4!!4JK0"N+I6M`^:4`
M`8MK`06+A?U;TZ44#*IE026+J_U"TVUY#:JK?$"2SP$-RN(!`DI*0"J+HF]`
M^4(``8M*`0*+8OU;TT(4"ZI"02*+BOU"TTQY#*I*?$"2KP$,RN4!!4JN0"Z+
MI7-`^:4``8O.`06+1?U;TZ44"JK%026+;OU"T\MY"ZJN?$"2CP$+RN(!`DI-
M0"V+HG=`^4(``8NM`0*+POU;TT(4#JJB02*+3?U"TZIY"JI-?$"2;P$*RN4!
M!4JL0"R+I7M`^:4``8N,`06+I?U;TZ44#:J%026+S/U"TXYY#JJL?$"23P$.
MRN(!`DI+0"N+HG]`^4(``8MK`0*+@OU;TT(4#*IB02*+J_U"TVUY#:I+?$"2
MSP$-RN4!!4JJ0"J+I8-`^:4``8M*`06+9?U;TZ44"ZI%026+BOU"TTQY#*JJ
M?$"2KP$,RN(!`DI.0"Z+HH=`^4(``8O.`0*+0OU;TT(4"JK"02*+;OU"T\MY
M"ZI.?$"2CP$+RN4!!4JM0"V+I8M`^:4``8NM`06+Q?U;TZ44#JJE026+3?U"
MTZIY"JJM?$"2;P$*RN(!`DI,0"R+HH]`^4(``8N,`0*+HOU;TT(4#:J"02*+
MS/U"TXYY#JI,?$"23P$.RN4!!4JK0"N+I9-`^:4``8MK`06+A?U;TZ44#*IE
M026+J_U"TVUY#:JK?$"2SP$-RN(!`DI*0"J+HI=`^4(``8M*`0*+8OU;TT(4
M"ZI"02*+BOU"TTQY#*I*?$"2KP$,RN4!!4JN0"Z+I9M`^:4``8O.`06+1?U;
MTZ44"JK%026+;OU"T\MY"ZJN?$"2CP$+RN(!`DI-0"V+HI]`^4(``8NM`0*+
MPOU;TT(4#JJB02*+3?U"TZIY"JI-?$"2;P$*RN4!!4JO_4+3K$`LBZ6C0/GO
M>0VJI0`!BXP!!8NE_5O3I10-JH5!)8O,_4+3L'Q`DHYY#JI,`0[*@@$"2DQ`
M*XO+`0_*90$%2J5`*HNBJU2I0@`!BT$!`8N,`0*+`OY;TZ$``8L%_D+30A00
MJJ5X$*J"02*+ZP$%BDQ\0)**_5O32A4,JC)`*HOA`06J(@`"BE!^0))"``LJ
MJJ]`^8&;E])AX['R2T`NBTH!`8MJ`0J+"_Y;TVL5$*I102N+BOU"TRU^0)*K
MLT#Y3GD,JJH`#JJL``Z*2@$2BFL!`8M*`0PJ0D$OBZK]6]-"``N+2A4-JD]`
M*HL"_D+30G@0JO!]0)++`0*JR@$"BFL!$8IK`0HJ94$EBZNW0/EK`0&+I0`+
MBPO^6]-K%1"JL4`KBZ7]0M,L?D"2J[M`^:UX#:I%``VJ:P$!BZ4`#XI/``V*
MI0`/*JI`+HN%_5O32@$+BZ44#*I/026+"OY"TTIY$*KP?4"2JP$*JJ4!"HIK
M`1&*:P$%*F)!(HNKOT#Y:P$!BT(`"XL+_EO3:Q40JE%`*XN"_4+3+GY`DJO#
M0/E,>`RJ0@$,JFL!`8M"``^*3P$,BD(`#RI%0"V+POU;TZ4`"XM"%`ZJKT`B
MBP7^0M.E>!"J\'U`DHL!!:J"`06*:P$1BFL!`BIJ02J+J\=`^6L!`8M*`0N+
M"_Y;TVL5$*I102N+ROU"TRU^0)*KRT#Y3GD.JJH`#JIK`0&+2@$/BJ\`#HI*
M`0\J0D$LBZK]6]-"``N+2A4-JD]`*HL"_D+30G@0JO!]0)++`0*JR@$"BFL!
M$8IK`0HJ94$EBZO/0/EK`0&+I0`+BPO^6]-K%1"JL4`KBZ7]0M,L?D"2J]-`
M^:UX#:I%``VJ:P$!BZ4`#XI/``V*I0`/*JI`+HN%_5O32@$+BZ44#*I/026+
M"OY"TTIY$*KP?4"2JP$*JJ4!"HIK`1&*:P$%*F)!(HNKUT#Y:P$!BT(`"XL+
M_EO3:Q40JE%`*XN"_4+3+GY`DJO;0/E,>`RJ0@$,JFL!`8M"``^*3P$,BD(`
M#RI%0"V+POU;TZ4`"XM"%`ZJKT`BBP7^0M.E>!"J\'U`DHL!!:J"`06*:P$1
MBFL!`BIJ02J+J]]`^6L!`8M*`0N+"_Y;TVL5$*I102N+ROU"TRU^0)*KXT#Y
M3GD.JJH`#JIK`0&+2@$/BJ\`#HI*`0\J0D$LBZK]6]-"``N+2A4-JD]`*HL"
M_D+30G@0JO!]0)++`0*JR@$"BFL!$8IK`0HJ94$EBZOG0/EK`0&+I0`+BPO^
M6]-K%1"JL4`KBZ7]0M,L?D"2J^M`^:UX#:I%``VJ:P$!BZ4`#XI/``V*I0`/
M*JI`+HN%_5O32@$+BZ44#*I.026+"OY"TTIY$*K0?4"2JP$*JJ4!"HIK`1&*
M:P$%*F)!(HNK[T#Y:P$!BT(`"XL+_EO3:Q40JE%`*XN"_4+3+WY`DJOS0/E,
M>`RJ0@$,JFL!`8M.``Z*0@$,BLX!`BK%02V+[?U;TZ4`"XNM%0^JHD`MBP7^
M0M-.?$"2I7@0JHL!!:J-`06*:P$1BFL!#2IJ02J+J_=`^6L!`8M*`0N+R_U;
MTVL5#JI+02N+ZOU"TVU]0))/>0^JJ@`/JD(!`HJJ``^*0@`**JK[0/E"0"R+
M00$!BT$``8NB_5O30A0-JB)`(HO!_4+32GQ`DBYX#JKA`0[*(0`+2JO_0/DE
M0"6+P3J8TD%,N?)K`0&+JP`+BT7]6].E%`JJ94$EBZO]0M.L?$"2;7D-JLL!
M#<IB`0)*JP-!^4)`+XMK`0&+2P`+BX+]6]-"%`RJ8D$BBTO]0M-J>0JJ2WQ`
MDJ\!"LKE`05*KD`NBZ4'0?FE``&+S@$%BV7]6].E%`NJQ4$EBX[]0M/,>0RJ
MKGQ`DD\!#,KB`0)*34`MBZ(+0?E"``&+K0$"B\+]6]-"%`ZJHD$BBVW]0M.K
M>0NJ37Q`DH\!"\KE`05*JD`JBZ4/0?FE``&+2@$%BZ7]6].E%`VJ14$EB\K]
M0M-.>0ZJJGQ`DF\!#LKB`0)*3$`LBZ(30?E"``&+C`$"BT+]6]-"%`JJ@D$B
MBZS]0M.->0VJ3'Q`DL\!#<KE`05*JT`KBZ470?FE``&+:P$%BX7]6].E%`RJ
M94$EBTO]0M-J>0JJJWQ`DJ\!"LKB`0)*3D`NBZ(;0?E"``&+S@$"BV+]6]-"
M%`NJPD$BBX[]0M/,>0RJ3GQ`DD\!#,KE`05*K4`MBZ4?0?FE``&+K0$%B\7]
M6].E%`ZJI4$EBVW]0M.K>0NJK7Q`DH\!"\KB`0)*2D`JBZ(C0?E"``&+2@$"
MBZ+]6]-"%`VJ0D$BB\K]0M-.>0ZJ2GQ`DF\!#LKE`05*K$`LBZ4G0?FE``&+
MC`$%BT7]6].E%`JJA4$EBZS]0M.->0VJK'Q`DL\!#<KB`0)*2T`KBZ(K0?E"
M``&+:P$"BX+]6]-"%`RJ8D$BBTO]0M-J>0JJ2WQ`DJ\!"LKE`05*KD`NBZ4O
M0?FE``&+S@$%BV7]6].E%`NJQ4$EBX[]0M/,>0RJKGQ`DD\!#,KB`0)*34`M
MBZ(S0?E"``&+K0$"B\+]6]-"%`ZJHD$BBVW]0M.K>0NJ37Q`DH\!"\KE`05*
MJD`JBZ4W0?FE``&+10$%BZK]6]-*%0VJJD`JB\7]0M-/?4"2KG@.JF4!#LJB
M``)*I3M!^4)`+(NE``&+10`%B^+]6]-"%`^JHD`BBZ7]0M.M>`VJ17Q`DLP!
M#<J*`0I*2D$KBZL_0?EK`0&+2P$+BZK\6]-*%06J<$$JB^O]0M,,?D"2:WD/
MJJH!"\I"`0)*JD-!^4)`+HM*`0&+2@`*BZ+\0M.._5O317@%JF(!!<K.%0RJ
M0@`02DY!+HNJ``D+"A``^4E`+8O*?4"2HD=!^4(``8LB`0*+2?U;TRD5"JHB
M`0(+YP`""P<$`/F'_4+3YW@,JJ4`!\KF``8+I0`.2J=+0?D&#`#Y1OQ;TZ5`
M*XOA``&+PA0"JJ$``8M!``$+(0`#"P$``/FA3T'Y`@%`^2(``LI!_4+3(7@*
MJB0`!`L$"`#Y@@``M?U[P:C_0PJ1P`-?UDCZ_Y<?(`/5``<`M/U[O*FB``#P
M_0,`D?=C`ZE8*$'Y\U,!J?5;`JD8`P"T`P!`.:('@%(4`(!2?P``<6000GKC
M!Y\:XP(`-1,#0/GS`0"T]P,!JO8#`*J4?D"3]0,8JN`#$ZKB`Q2JX0,6J@7Z
M_Y>````U8&IT.!_T`'$@`@!4LXY`^//^_[4``(#2\U-!J?5;0JGW8T.I_7O$
MJ,`#7];T`P"J@QY`.'\``'%D$$)ZH?__5)0"`$OD__\7'R`#U:("&,N`!@"1
M8`(`BT+\0Y/B`@"Y\U-!J?5;0JGW8T.I_7O$J,`#7]8``(#2P`-?UOU[O*G]
M`P"1\U,!J?,#`*KU$P#YM0``\*`B"9&T``#P`0!`^:$?`/D!`(#2H=,`D>`#
M$ZJY__^7X`$`M((J0?FC-X"Y0`P#BP$$0/E!>"/XX?[_M``@`)$!!$#Y`0``
M^:'__[6ATP"1X`,3JJO__Y=@_O^UM2()D:$?0/F@`D#Y(```RJ```+7S4T&I
M]1-`^?U[Q*C``U_6YOG_EQ\@`]7]>[FI_0,`D?-3`:GS`P&J]5L"J?0#`*KW
M8P.IM0``\/EK!*FA(@F1^RL`^6`"0#DB`$#YHC<`^0(`@-(?]`!Q<Q:3FN`#
M$ZI>^?^7]P,`JJ&3`9'@`Q2JB/__ER`(`+3V`P"J5_G_EQ]`-^OB!@!4MF=`
MN;@``/"``D`YH@>`4A\``'$$$$)ZP`L`5.$#%*H@'$`X'P``<0000GJA__]4
M(0`42^`*`!$7*T'Y```!"_8#%BI_^?^7X'HV^,`*`+0"*T'YHP>`4J1G0+F`
M!@"1@0)`.3\``'%">&3X)!!#>D$``#G```!4`11`.#\``'%!'``X)!!#>H'_
M_U2@!X!2000`D4```#E@%D`X(!0`.,#__S4``(!2M2()D:(W0/FA`D#Y00`!
MRJ$'`+7S4T&I]5M"J?=C0ZGY:T2I^RM`^?U[QZC``U_6``"`TF%J8#C!:B`X
M``0`D:'__S7N__\7N```\!HK0?E``T#YX`0`M.$#&JH``(!2`P``%!\@`]7@
M`Q8J(HQ`^!8$`!&B__^U``P`$0!\?9.A``#P(F!"N8(!`#3A`P"JX`,:JG'Y
M_Y<`*P'Y``,`M-E^0),Y!P"1'W@Y^+9G`+FL__\7'R`#U2(`@%(B8`*Y-OG_
ME_L#`*J@`0"TV7Y`D^$#&JHB\WW3[/C_EQLK`?G@`QNJ\/__%P$`@%*H__\7
M``*`TA8`@%+B__\7``"`$L#__Q==^?^7_7NSJ?T#`)'S4P&IM```\/5;`JF!
M(@F1]V,#J2(`0/FB9P#Y`@"`TH```+0!`$`Y]0,`JF$!`#64(@F1H6=`^8`"
M0/D@``#*H`@`M?-30:GU6T*I]V-#J?U[S:C``U_6Z/C_E_8#`*J`_O^T&```
MT!B#$I'@`Q:JAOG_E^4#`*K@!`"TH$Q`.1^X`'$@!0!4X`,5JK-,`)'"^/^7
M]P,`JN`#$ZJ_^/^7```7"P`(`!$`?$"3]_C_E_<#`*KE`Q.JY`,5JN,#&*H"
M`("2(0"`4KCX_Y>B(P&1X0,7J@``@%*\^/^7'P0`,:```%2@6T"Y``P4$A\0
M0''``@!4X`,7JISY_Y?@`Q>J6OG_E^`#%JI@^?^7Y0,`JF#[_[7@`Q:J$/G_
ME^`#%:H^^?^7P___%Z!00#D`^O\T'[@`<:'Z_U2@5$`Y@/G_--+__Q<?(`/5
MX`,7JJO__Y?K__\7!?G_E_U[OJG]`P"1\U,!J;,``/#T`P"J8#I"N?+X_Y<"
MX`>1X0,4J@``@%(R^?^7H```-```@%+S4T&I_7O"J,`#7]9@.D*YY_C_EP`(
M0KD`#!02'Q!`<>```%1@.D*YX?C_EP`(0KD`#!02'RA`<2'^_U3@`Q2J00"`
M4OKX_Y<?``!QX!>?&O-30:G]>\*HP`-?UO\'0-$"``#0_T,`T?U[O:G]`P"1
M]5L"J?4#`*KS4P&ILP``\&,B"9%`H!*1]@,!JF0`0/FD'PCY!`"`TJ'C`)'B
M_X'2:_C_EQ\``'$-!`!4`@0`4:$#/]%4?$"3(0`4BR'@?SDA`P`T%'Q`D^(#
M%*J@XP"1X06`4BKY_Y>``@"TH```\``X0KFR^/^7XP,4JJ+C`)'A`Q6J*OG_
MEW,B"9&A'TCY8`)`^2```,K@`0"U\U-!J?5;0JG]>\.H_P=`D?]#`)'``U_6
M(OW_-:```/``.$*YG_C_E^(#%JKA`Q6J?/C_E^[__Q>F^/^7'R`#U:```/#]
M>[^I_0,`D0`X0KF4^/^7`P``T.+__]`!``#08T`/D?U[P:A"@#>1(>`2D<SX
M_Q<?(`/5_7N^J?T#`)'S"P#YLP``\&`Z0KF%^/^7[/__EV`Z0KF"^/^7\PM`
M^00``-`"``"PA(`@D0$``-#]>\*HXP,$JD+`.I$A8!.1!0"`4M?X_Q?_"T#1
M_X,`T?U[O:G]`P"1]1,`^;4``/#S4P&IH"()D0$`0/FA)Q#Y`0"`TCOX_Y?D
M`P`J!0``T`,``-"EP!.18^`3D:#C`)$B`(+2(0"`4O[W_Y?@`_@W`@B"TJ#C
M`)&A`P*+`@""T@3X_Y?S`P"J``/X-P`$`!$`?$"3*_C_E_0#`*I@`@"T<WY`
MDP$(@M*A`P&+X@,3JMSW_Y>?:C,XX`,4JK4B"9&B)U#YH0)`^4$``<HA`0"U
M\U-!J?430/G]>\.H_PM`D?^#`)'``U_6``"`TO3__Q=,^/^7'R`#U<C__Q<?
M(`/5_P=`T0(``-#_0P#1_7N[J?T#`)'S4P&I]`,`JO5;`JFV``#P]V,#J4!`
M%)'Y:P2IPB()D?,#`:JA4P&10P!`^:,O"/D#`(#2\/W_E_4#`*K@`Q2JX06`
M4HKX_Y=@`@"T````T.$#%*H`@!212?[_E^`#%*K6(@F1HB](^<$"0/E!``'*
MX0H`M?-30:GU6T*I]V-#J?EK1*G]>\6H_P=`D?]#`)'``U_6X`,4JA@``-"H
M]_^7^0,`*@'#%)'@`Q.JH/?_E_,#`*K`_/^T%P``T!H``-#W(A21.0<`$5KC
M%)%@`D`Y'P``<7,2EYJU``"TX0,3JN`#%:HN^/^7``4`-.`#$ZJ3]_^7X0,`
M*F#"((L`\%\X'[P`<>$``%0A!`!18,(ABW_*(3@`\%\X'[P`<6#__U0A`P$+
M/_P_<2SY_U0#``#0Y`,3JN8#%*KE`QJJ8P`5D:!C`9$"`(+2(0"`4K,``/!_
M]_^78#I"N>'W_Y<"X`>1H6,!D0``@%*!]_^7X```-6`Z0KG:]_^7``A"N0`,
M%!(?($!QX```5`'#%)$``(#29_?_E_,#`*J@^?^UK/__%Z!C`9$A`(!2[??_
ME^#^_S4```#0H6,!D0"`%)'P_?^7H&,!D8;W_Y>F__\7T/?_EQ\@`]4!`$`Y
MP0``-`($`)$_O`!Q`!""FD$40#BA__\UP`-?UOU[OJG]`P"1\U,!J6`#`+04
M`$`Y\P,`JA0#`#1+]_^7``0`T6("`(M_`@+K8@0`5&!J8#@?O`!QH```5!P`
M`!1``$`Y'[P`<2$#`%1"!`#1?P("ZV'__U2?O@!QX```5/-30:D```"P_7O"
MJ`#@%)%>]_\7'R`#U4``@-)O]_^70`4`M`(``+!"(!210@!`>0(``'GS4T&I
M_7O"J,`#7]9``$`Y'[P`<8`!`%1"!`#1?P("ZV/__U1_`@+KX/S_5$($`-%_
M`@+KX@``5$``0#D?O`!Q@0``5$($`-%_`@+K8___5$(`$\M`"`"1'P1`\<@!
M`%2@``#0X0,3J@"`"9%"!`"1$R``D0,`@M+@`Q.J3O?_E^`#$ZKS4T&I_7O"
MJ,`#7]8?(`/5``"`TO-30:G]>\*HP`-?UOU[N*D!``"P(4`/D0```+#]`P"1
M\U,!J;,``-#U6P*I8R()D?<;`/D`(!61)AQ!J6(`0/FB/P#Y`@"`TB040JFF
M'P6I(6!`>14``+"D%P:I%@``L*'C`'D7``"P%```L%3]_Y>4HA:1````L`!@
M%9%0_?^7````L`"`%9%-_?^7````L`#`%9%*_?^7H.(5D4C]_Y<```"P`"`6
MD47]_Y?`0A210_W_E^!B%I%!_?^7X`,4JC_]_Y<```"P`.`6D3S]_Y<```"P
M`(`4D3G]_Y<```"P`"`7D3;]_Y<```"P`&`7D3/]_Y<```"PH3,!D0"@%Y'U
M_/^7@```M.$#`*K@`Q2J4_W_EP```+"A,P&1```8D>W\_Y>@``"T`@``L.$#
M`*I`8!B12OW_EP```+"A,P&1`*`8D>3\_Y=@`@"TX0,`JL!"%)%"_?^7`0``
ML*#B%9$A@!F1<R()D3W]_Y>A/T#Y8`)`^2```,I@`P"U\U-!J?5;0JGW&T#Y
M_7O(J,`#7]8?(`/5````L*$S`9$`X!B1S?S_E\```+3A`P"JX&(6D2O]_Y?I
M__\7'R`#U0$``+"@AP&1(4`9D4(!@-+@]O^70/S_-:&O`9'@8A:1(/W_E][_
M_Q<"]_^7'R`#U?U[O:G]`P"1\U,!J;0``-"S``#08"()D0$`0/FA%P#Y`0"`
MTH`B0KD?!``Q(`$`5',B"9&B%T#Y80)`^4$``<JA`@"U\U-!J?U[PZC``U_6
M````L*&3`)$`8!:1H_S_ET`!`+0!`$`Y/\``<>('GQH_``!QX`>?&D````J`
M(@*Y[/__%Q\@`]4``(!2@"("N>C__Q?;]O^7_7N_J?T#`)%X]O^7__;_EX``
M`+0``$#Y_7O!J,`#7]8``(#2_?__%P$``+#]>[:I(4`/D?T#`)'S4P&I]5L"
MJ?8#`*HSF$.I]V,#J2'@`)'Y:P2IMP``T+,;!JGB(@F1(!A`^4,`0/FC3P#Y
M`P"`TB040:F@2P#Y(@Q"J:07!ZFB#PBI$P,`M`$``+````"PM:,!D3G`%)$8
M`!61!@``%.$#%JHI]_^70`,`M+.&0/BS`0"TH7,!D>`#$ZIE_/^7]`,`JF``
M`+0!`$`YH?[_->`#$ZKA`Q:JP/S_E[.&0/BS_O^U]R()D:%/0/G@`D#Y(```
MRF`#`+7S4T&I]5M"J?=C0ZGY:T2I_7O*J,`#7];@`Q:J(?;_E_H#`*K@`Q2J
M'O;_ET`#`(L`"`"15_;_E_H#`*KF`Q2JY0,9JN0#%JKC`QBJ`@"`DB$`@%(7
M]O^7X0,:JN`#$ZJ@_/^7U/__%X+V_Y<?(`/5_R-`T0$``+#_0P71(4`/D2(@
M`I$CX`*1_7NZJ?T#`)'U6P*I]0,`JB!`0/DD%$>IH$L`^4`$0*GS4P&IH`<+
MJ;-C`I%`!$&II!<(J:`'#*FA\P&11!1"J?=C`ZE@"$#YMP``T&(,0*GY:P2I
M^W,%J1D``+!B#@"I`S60TN(B"9&C`P.+_T,`T:07#:E@"@#Y1`!`^60``/D$
M`(#2($,4D1+\_Y>```"T`0!`.?0#`*K!(0`U>?__EQ8`@-+T`P"JP`\`M.`#
M%*K:]?^7`/A_TP`$`)$3]O^7]@,`JH0"0#D```"P\P,6JAC`&9$D`0`TX`,3
MJN,#&*H"`("2(0"`4G,*`)'/]?^7A!Y`."3__S6@6T#YM,,"D8```+4/```4
M@(Y`^*`!`+2A\P&1[_O_E_,#`*I@__^T`0!`.2'__S0L_?^7X/[_-.`#$ZKA
M]?^7\P,`JN`"`+6S0T#Y,PP`M&`"0#DT`(!28`$`-5T``!0"-I#2H`,"BP#,
M-(L`)$#1$VA'^?,*`+1@`D`YE`8`$8`*`#3@`Q.J%OW_EZ#^_S3@`Q.JR_7_
ME_,#`*H@_O^TX`,3JA@``+">]?^7]`,`JN`#%JJ;]?^7```4"QH0$!%:?T"3
MX`,:JM+U_Y?T`P"J!@``L`,``+#G`Q:JQN`9D>0#$ZIC`!J1!>,4D0(`@)(A
M`(!2C_7_E^`#%*H!.(!2@/;_EQ\$`#&`!@!4LP``T&`Z0KGK]?^7`N`'D>$#
M%*H``(!2*_;_ET`'`#2@``#0`@``L*,"0/GD`Q2J0F`<D2$`@%(`&$'Y"O;_
MEP``@-(!-9#2]R()D:$#`8LB`$#YX0)`^4$``<H!.`"UOP,`D?-30:GU6T*I
M]V-#J?EK1*G[<T6I_7O&J/\C0)'_0P61P`-?UA\@`]6*]?^7]`,`JJ#P_[76
M(@"1P&IS^.`1`+2A\P&1B?O_EV#__[0!`$`YP?[_-=8B`)'X__\7'R`#U1,`
M@-*S__\70O;_EP4`0+F_1`!Q0/G_5*```-`"``"PHP)`^>0#%*I"0!J1(0"`
M4@`80?G;]?^7``"`TM'__Q=@.D*YJ_7_EP`(0KD`#!02'Q!`<4'X_U1@.D*Y
MI?7_EQ800KE/]?^7WP(`:X'W_U1@.D*YG_7_EP`(0KD`(``2'P`'<<'V_U3@
M`QJJ;?7_E_,#`*H```"PH?,!D0!@(I%:^_^7(`P`M+8"0/E1]?^7X0,`JN`#
M%JI2_?^7]@,`JD`+`+3@`Q:J(O7_EQ\,`''Z`P"J[0$`5`!\0),!``"P`!``
MT2%`&Y'``@"+L?7_EP`!`#5?$P!Q0"4`5$`3`%'`PB"+`/!?.!^\`'&@)`!4
MA/[_E\```#7@`Q:J`0"`4NSU_Y?Z`P`J0`@`-0$``+````"P(8`9D0!@%I$8
MXQ21%@``L/H#&*H5`(!2D?O_E]8"')$W]?^7Y@,`*@<``+`#``"PYX`@D>4#
M&*ICP!N1Y`,4JN`#$ZH"`("2(0"`4O@#!ZKW]/^7$@``%!\@`]7@]?^7``!`
MN1]$`'%!`@!4)/7_E[4&`!'F`P`JYP,5*N4#&JKD`Q2JXP,6JN`#$ZH"`("2
M(0"`4O@#`/GE]/^7X`,3J@$X@%+6]?^7'P0`,8#]_U3@`Q2JCO7_E^$#$ZH@
M0Q219_O_E^`#$ZIY_O^7X`,3JE___Q=V_O^7X`,4JOCT_Y=;__\7%```L*`!
M@-*4HAF1]/[_%[8"0/FF__\70@"`4B$"@)(F]?^7H:,&D>`#&BK"`(#2FO7_
MEZ"C1CF````UH*=&.1\,`7'@'0!4X`,:*@(`@%(!`(#2&?7_E[__$*DA8(32
M('&5TJ'HK/*@^;WRPI^;TK];`;FA`PZIP8Z*T@`^G-)!!J+R0'JX\D(7L_*A
M@P^IH&,$D?P#`*JB>P#YH#<`^:&C!I'@`QHJ`@"0TGOU_Y<?``!Q^P,`JO8#
M`"JM"`!4HH=`^6!_0)-!#``+7P`!ZZ*+0/E)``!40@0`D4!T0(NA@Q"IH%M!
MN<`4`#0!"(!2-@``2Z$W0/E_`Q9K=M.6&B#`((NAHP:1U7Y`D^(#%:I^]/^7
MH%M!N<`"``L?``%QH%L!N>'[_U2@HP:1=@,62QL`%8N@@P.15O;_E]_^`'$-
M%`!4U@(!4<!^!E,59'K3M0(!D:!G`+EU`Q6+9A]`J:"#`Y%D%T&IAA\`J6(/
M0JF$%P&I:"=#J8(/`JF()P.I>P,!D4/V_Y>_`AOK@?[_5*!G0+G6&@!+H#=`
M^<)^0)/A`Q6J`PF`TICT_Y>V6P&YH:,&D>`#&BH"`)#2-_7_EQ\``''[`P"J
M]@,`*JSW_U3@`QHJT?3_E[;74*FB0SG1P2)#TR`$`!%!P"&+X@^`$A_@`'$B
MH#TYC`X`5`('@%*A8P210@``2R#`((L!`(!20GQ`DYWT_Y>A_E#3HOY8TZ"#
M`Y&U3P4YH4<%.<'^6-.U_DC3HD,%.:%3!3G"_E#3P?Y(T[5+!3FB5P4YNH<%
MD;9?!3FVXP61H5L%.0WV_Y>E#TZIVZ(`D:6/!3FB!T^II'Q8TZ;\4-.E_$C3
MHY\%.:6+!3EE_%C3HJ\%.:63!3EE_%#38_Q(TZ"#0/FAOP4YHYL%.4/\6-.@
MSP4YHZ,%.4/\4--"_$C3I(,%.::'!3FBJP4Y(OQ8TZ67!3FBLP4Y(OQ0TR'\
M2-.CIP4YHK<%.0+\6-.ANP4Y`?Q0TP#\2-.BPP4YH<<%.:#+!3D```"P%<`9
MD0(``!1$%T`XX`,6JN,#%:H"`("2(0"`4M8*`)$*]/^7?P,6ZP'__U0'``"P
M`P``L.>`()&FXP61!>,4D>0#%*IC@!N1X`,3J@(`@)(A`(!2OX,&.?SS_Y?@
M`Q2JJO3_E^$#$ZH@0Q21@_K_E^`#$ZJ5_?^7X`,3JGO^_Q>[HP:1;O__%[4&
M0/EUV_^TX`,5JNGS_Y<?#`#QZ=K_5``0`-$!``"P(6`;D:`"`(MZ]/^7'P``
M<=82E9K/_O\7]0,;JG7__Q<""(!2NF,$D4(``$L!`(!20,,@BT)\0),J]/^7
MH(,#D:KU_Y=??P"I7W\!J5]_`JE?&P#YA___%Z"K1CD?!`%Q`>+_5*"O1CD?
M#`%QH>'_5*"S1CD?(`%Q0>'_5*"W1CD?%`%QX>#_5.`#&BI"`(!2(0>`DA_T
M_Y>AHP:1X`,:*B(%@-*3]/^7!P``L`,``+#G@""1IJ,&D07C%)'D`Q2J8X`;
MD>`#$ZH"`("2(0"`4K3S_Y?4_O\7(O3_EQ\@`]7]>[FIH```T``@"9']`P"1
M^6L$J;D``-#S4P&I]5L"J?=C`ZG[<P6I`0!`^:$W`/D!`(#2(#M"N0;T_Y<C
M`(!2`@``L*&3`9$#Q`(Y0.`5D<;Y_Y>```"T`0!`.3_$`''`$`!4C_S_ER`[
M0KF[``#P^//_EP$``+!C`8!2(<`=D2(`@%(']/^7H`8`M'6##9$!"$#YH()0
MN#<40/D?!`!Q[04`5!B`@%(VXPB1%`"`4C,`@%(8!*!R"P``%!\@`]4A"$#Y
MX`,:JA+T_Y?@`P`UH()0N',&`!&4!@`1'P`3:XT#`%3``D"YVO/_EX)^0)/A
M`Q>J`P"`4C[T_Y?\`P"J0`(`M`$`0/FB`E'X(`Q`N5K8<_@``!@*'P`0<2#]
M_U3``D"YR_/_EX$#0/E#`(!2`@"`TK?S_Y?A`P"JX`,:JO3S_Y=@_/\T8(,-
MD0"`4+@!!`!1/P`4:X`)`%0@.T*YO//_EP$``)!C`(!2(>`=D2(`@%++\_^7
M\P,`JH`!`+0@.T*YL_/_EV$*0/D"``"00@`>D2$`0/F.\_^78`I`^0``0/D`
M#$"Y(!"P-R`[0KFH\_^7`0``D&,`@%(A(!Z1(@"`4K?S_Y?S`P"JH`$`M```
M`)"ADP&1`(`4D6/Y_Y?T`P"J(#M"N10+`+29\_^780I`^>(#%*HA`$#Y=?/_
MER`[0KEU@PV1DO/_EQ_$`CD"``"0H9,!D4!`%)%3^?^7H((1^/0#`*K`!`"T
M`3B`4ACT_Y<!!``1/P0`<02(47JA#`!4H```L!H@"9&A-T#Y0`-`^2```,K`
M"P"U\U-!J?5;0JGW8T.I^6M$J?MS1:G]>\>HP`-?U@`$0#E@[_\T>?__%Q\@
M`]4?!`!QC?;_5#7C")%T@PV1,P"`4J`"0+ES!@`1:_/_E^$#%ZH=\_^7@()0
MN!\`$VLL__]4J/__%Z`"4?CO_/^7H((1^,`'`+1A"D#Y`("`4@`$H'(A`$#Y
M(@Q`N4````H?`!!Q`04`5"`(0/E[@PV1=`-1^.$#%*I\\_^7]0,`*F$*0/D`
M@(!2``2@<I0"0/DA`$#Y(@Q`N4````H?`!!Q`0(`5"((0/D```"0XP,5*N$#
M%*H`X!Z1@//_EQ\@`]5"\_^78(,-D6(*0/D!`%'X0`!`^2$`0/EH^O^7I___
M%R`[0KDY\_^780I`^0(`@-)#`(!2(0!`^23S_Y?B`P"JZO__%R`[0KDP\_^7
M80I`^4,`@%("`(#2(0!`^1OS_Y?3__\7(#M"N2CS_Y=A"D#Y(0!`^7WS_Y=[
M__\7````D`!`'I%=\_^7+//_EZ$"4?@$``"0XP,`*N(#%*J`@!^1(0!`^57S
M_Y?]>[ZI_0,`D?-3`:GT`P"J6OO_E_,#`*H``$`YP```-&$&`)$?O`!Q<Q*!
MFB`40#B@__\U%_S_EY\"`/$$&$!Z(`$`5(`"0#G@```T`0``D.`#$ZHAX!F1
MAO/_EW\"`.N```!4\U-!J?U[PJC``U_6X`,4JO-30:G]>\*HJ?G_%Z,``+!D
M8`B19```M&,,0?FP\O\7`P"`TJ[R_Q?]>[RI_0,`D?-3`:GU6P*IM```D+4`
M`)"U`C>1E"(WD90"%<OV`P*JE/Y#DQ,`@-+W8P.I^`,`*O<#`:I@\O^7-`$`
MM*-Z<_CB`Q:JX0,7JN`#&"IS!@"18``_UG\"%.LA__]4\U-!J?5;0JGW8T.I
M_7O$J,`#7];``U_6_7N_J?T#`)']>\&HP`-?U@$``@``````<&5R;'AS:2YC
M`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````````
M``!X6$```````(A80```````D%A```````"86$```````*!80```````N%A`
M`````````````````'!80```````"%5``````````````````!A60```````
M4%A```````!86$```````&!80```````:%A``````````````````#A80```
M````0%A``````````````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z
M.D)/3U0`````97AE```````O<')O8R\E:2\E<P``````+@````````!005)?
M5$5-4```````````4$%27U!23T=.04U%`````#H`````````+P`````````E
M<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4````````
M``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%2
M7T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#2$4`````````
M4$%27T%21T,``````````%!!4E]!4D=67S````````!005)?1TQ/0D%,7T1%
M0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2
M````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````````
M`%!!4E]#3$5!3CT````````Q`````````%-94U1%30``)3`R>`````!P87(M
M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````<&%R;```
M```N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E
M<W1E;7`M)74M)74E<P``````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@```````$%21U8`````&`````````!P97)L`````#``
M````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````````
M`"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```````````M90```````"TM````````55-%4@``
M``!54T523D%-10``````````5$U01$E2``!414U01$E2`%1%35``````5$U0
M```````O=&UP`````$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?
M4$%42`````!$64Q$7TQ)0E)!4EE?4$%42`````````!32$Q)0E]0051(````
M````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E
M(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O
M8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G
M)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E
M86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D
M=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R
M/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I
M"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?
M05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@
M)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q
M*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@
M)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\
M)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY
M("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O
M9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q
M<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@
M/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D
M(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T
M.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@
M)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R
M."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X]
M(#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@
M,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N
M<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE
M("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D
M8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D[
M"FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@
M*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@
M/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN
M960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2![
M"FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I
M.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68[
M"F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]4
M14U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN
M(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*
M96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T
M*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA
M<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M
M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U
M="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*
M?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H
M)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O
M<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM
M>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL
M7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF
M>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I
M('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`
M05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D
M9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)
M34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2![
M"G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*
M979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@
M0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D
M,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*
M96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@
M*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I
M('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@
M;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N
M86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC
M*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*
M?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`[
M"FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B
M0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z
M("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H
M9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D
M(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!
M4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D
M92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S
M(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R
M(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO
M861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@
M>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D
M=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!
M4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H
M)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^(&QE;F=T
M:"@D82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL
M97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R
M:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F
M:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X
M="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I
M9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE
M;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N
M86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]
M"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]
M7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@
M*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE
M86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'@D0```````2"1```````````````````$`
M`````````0`````````!`````````,0!`````````0`````````3`@``````
M``$`````````9@,````````,`````````/@<0```````#0````````"X4T``
M`````!D`````````P)U!```````;``````````@`````````&@````````#(
MG4$``````!P`````````"`````````#U_O]O`````&`"0```````!0``````
M```8$$````````8`````````$`9````````*`````````.4$````````"P``
M```````8`````````!4````````````````````#`````````.B?00``````
M`@`````````P!@```````!0`````````!P`````````7`````````,@60```
M````!P`````````X%D````````@`````````D``````````)`````````!@`
M````````_O__;P````#8%4```````/___V\``````P````````#P__]O````
M`/X40```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````V)U!````````````````````````````````````
M`````````````!`=0```````$!U````````0'4```````!`=0```````$!U`
M```````0'4```````!`=0```````$!U````````0'4```````!`=0```````
M$!U````````0'4```````!`=0```````$!U````````0'4```````!`=0```
M````$!U````````0'4```````!`=0```````$!U````````0'4```````!`=
M0```````$!U````````0'4```````!`=0```````$!U````````0'4``````
M`!`=0```````$!U````````0'4```````!`=0```````$!U````````0'4``
M`````!`=0```````$!U````````0'4```````!`=0```````$!U````````0
M'4```````!`=0```````$!U````````0'4```````!`=0```````$!U`````
M```0'4```````!`=0```````$!U````````0'4```````!`=0```````$!U`
M```````0'4```````!`=0```````$!U````````0'4```````!`=0```````
M$!U````````0'4```````!`=0```````$!U````````0'4```````!`=0```
M````$!U````````0'4```````!`=0```````$!U````````0'4``````````
M``````````````````#_____`````,A80```````1T-#.B`H56)U;G1U+TQI
M;F%R;R`U+C,N,2TQ,'5B=6YT=3(I(#4N,RXQ(#(P,38P,C(U`$=#0SH@*%5B
M=6YT=2],:6YA<F\@-"XY+C,M,3)U8G5N='4Q*2`T+CDN,P``+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R
M`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```
M````````````````````````````````````````````````````````````
M``````````````````````````````````L````!`````@```````````D``
M```````"````````&P````````````````````$````````````````````3
M````!P````(`````````'`)````````<`@```````"``````````````````
M```$````````````````````(0````<````"`````````#P"0```````/`(`
M```````D````````````````````!````````````````````#0```#V__]O
M`@````````!@`D```````&`"````````K`,````````%``````````@`````
M```````````````^````"P````(`````````$`9````````0!@````````@*
M````````!@````$````(`````````!@`````````1@````,````"````````
M`!@00```````&!````````#E!````````````````````0``````````````
M`````$X```#___]O`@````````#^%$```````/X4````````U@`````````%
M``````````(``````````@````````!;````_O__;P(`````````V!5`````
M``#8%0```````&``````````!@````,````(````````````````````:@``
M``0````"`````````#@60```````.!8```````"0``````````4`````````
M"``````````8`````````'0````$````0@````````#(%D```````,@6````
M````,`8````````%````%@````@`````````&`````````!^`````0````8`
M````````^!Q```````#X'````````!0````````````````````$````````
M````````````>0````$````&`````````!`=0```````$!T```````!`!```
M````````````````$``````````0`````````(0````!````!@````````!0
M(4```````%`A````````:#(```````````````````@`````````````````
M``"*`````0````8`````````N%-```````"X4P```````!``````````````
M```````$````````````````````D`````$````"`````````,A30```````
MR%,```````"X0@``````````````````"````````````````````)@````!
M`````@````````"`ED```````("6````````!`````````````````````0`
M``````````````````"B````#@````,`````````P)U!``````#`G0``````
M``@````````````````````(````````````````````K@````\````#````
M`````,B=00``````R)T````````(````````````````````"```````````
M`````````+H````!`````P````````#0G4$``````-"=````````"```````
M``````````````@```````````````````"_````!@````,`````````V)U!
M``````#8G0`````````"````````!@`````````(`````````!``````````
MR`````$````#`````````-B?00``````V)\````````0````````````````
M````"``````````(`````````,T````!`````P````````#HGT$``````.B?
M````````*`(```````````````````@`````````"`````````#6`````0``
M``,`````````$*)!```````0H@```````"`````````````````````(````
M````````````````W`````@````#`````````#"B00``````,*(```````!8
M$```````````````````"````````````````````.$````!````,```````
M`````````````#"B````````7P````````````````````$``````````0``
M```````!`````P````````````````````````"/H@```````.H`````````
8```````````!````````````````````
